==> mkproject-0.0.16.tar.bz2: mkproject-0.0.16/src/mp.sh <==
#!/usr/bin/env bash

# Copyright (C) 2007 Juan Manuel Borges Caño

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

MP_PROJECTDIR="$MP_DATADIR/$1/project"

# basic functions

function printfi
{
	tput setaf 3; printf "$*"; tput sgr0
}

function echoi
{
	tput setaf 3; echo -e "$*"; tput sgr0
}

# mp functions

function mp_mkdir
{
	printfi "Creating directory $(basename "$1")..."
		mkdir "$1"
	echoi "done"
}

function mp_source 
{
	printfi "Creating $1..."
		source "$MP_PROJECTDIR/$1.sh" "$2" "$3" "$4" "$5"
	echoi "done"
}

function mp_source_as
{
	printfi "Creating $1..."
		source "$MP_PROJECTDIR/$2.sh" "$3" "$4" "$5" "$6"
	echoi "done"
}

function mp_cp
{
	printfi "Creating $1..."
		cp "$MP_PROJECTDIR/$1" "$2/$1"
	echoi "done"
}

function mp_exec
{
	printfi "Executing $1 for you (see $MP.log)..."
		cd "$2" &&
		echo "$1:" >> "$MP.log"; $1 >> "$MP.log" 2>&1 &&
		cd ..
	echoi "done"
}

==> mkproject-0.0.21.tar.bz2: mkproject-0.0.21/src/mp.sh <==
#!/usr/bin/env bash

# Copyright (C) 2007 Juan Manuel Borges Caño

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

MP_PROJECTDIR="$MP_DATADIR/$1/project"

# mp functions

function mp_mkdir
{
	if [[ -a $1 ]]
	then
		echo "Directory $(basename $1) exists."
		exit 1
	else
		printf "Creating directory $(basename "$1")..."
			mkdir "$1"
		echo "done"
	fi
}

function mp_source 
{
	if [[ -a $1 ]]
	then
		echo "File $1 exists."
		exit 1
	else
		printf "Creating $1..."
			source "$MP_PROJECTDIR/$1.sh" "$2" "$3" "$4" "$5"
		echo "done"
	fi
}

function mp_source_as
{
	if [[ -a $1 ]]
	then
		echo "File $1 exists."
		exit 1
	else
		printf "Creating $1..."
			source "$MP_PROJECTDIR/$2.sh" "$3" "$4" "$5" "$6"
		echo "done"
	fi
}

function mp_cp
{
	if [[ -a $1 ]]
	then
		echo "File $1 exists."
		exit 1
	else
		printf "Creating $1..."
			cp "$MP_PROJECTDIR/$1" "$2/$1"
		echo "done"
	fi
}

function mp_exec
{
	printf "Executing $1 for you (see $MP.log)..."
		cd "$2" &&
		echo "$1:" >> "$MP.log"; $1 >> "$MP.log" 2>&1 &&
		cd ..
	echo "done"
}
